==> estateplat-common-1.2.4-20220329.072424-992-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsSys.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/1/20
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:chenjia@gtmap.cn">chenjia</a>
*@Description: 核税系统的三要素
*@Date 10:19 2020/1/20
*/
@Entity
@Table( name ="YCSL_HS_SYS" )
public class YcslHsSys implements Serializable {
    /**
     * 三要素ID
     */
    @Column(name = "SYSID" )
    @Id
    private String sysid;
    /**
     * 交易id
     */
    @Column(name = "JYUUID" )
    private String jyuuid;
    /**
     * 税务机关代码
     */
    @Column(name = "SWJGDM" )
    private String swjgdm;
    /**
     * 纳税人识别号
     */
    @Column(name = "NSRSBH" )
    private String nsrsbh;
    /**
     * 税票号码
     */
    @Column(name = "DZSPHM" )
    private String dzsphm;
    /**
     * 标记
     */
    @Column(name = "BJ" )
    private String bj;

    public String getSysid() {
        return sysid;
    }

    public void setSysid(String sysid) {
        this.sysid = sysid;
    }

    public String getJyuuid() {
        return jyuuid;
    }

    public void setJyuuid(String jyuuid) {
        this.jyuuid = jyuuid;
    }

    public String getSwjgdm() {
        return swjgdm;
    }

    public void setSwjgdm(String swjgdm) {
        this.swjgdm = swjgdm;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getBj() {
        return bj;
    }

    public void setBj(String bj) {
        this.bj = bj;
    }
}

==> estateplat-common-1.2.4-20240108.082117-1212-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsSys.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/1/20
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:chenjia@gtmap.cn">chenjia</a>
*@Description: 核税系统的三要素
*@Date 10:19 2020/1/20
*/
@Entity
@Table( name ="YCSL_HS_SYS" )
public class YcslHsSys implements Serializable {
    /**
     * 三要素ID
     */
    @Column(name = "SYSID" )
    @Id
    private String sysid;
    /**
     * 交易id
     */
    @Column(name = "JYUUID" )
    private String jyuuid;
    /**
     * 税务机关代码
     */
    @Column(name = "SWJGDM" )
    private String swjgdm;
    /**
     * 纳税人识别号
     */
    @Column(name = "NSRSBH" )
    private String nsrsbh;
    /**
     * 税票号码
     */
    @Column(name = "DZSPHM" )
    private String dzsphm;
    /**
     * 标记
     */
    @Column(name = "BJ" )
    private String bj;
    /**
     * 权利人类别
     */
    @Column(name = "QLRLB" )
    private String qlrlb;
    /**
     * 缴款金额
     */
    @Column(name = "JKJE" )
    private Double jkje;

    public String getSysid() {
        return sysid;
    }

    public void setSysid(String sysid) {
        this.sysid = sysid;
    }

    public String getJyuuid() {
        return jyuuid;
    }

    public void setJyuuid(String jyuuid) {
        this.jyuuid = jyuuid;
    }

    public String getSwjgdm() {
        return swjgdm;
    }

    public void setSwjgdm(String swjgdm) {
        this.swjgdm = swjgdm;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getBj() {
        return bj;
    }

    public void setBj(String bj) {
        this.bj = bj;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlb) {
        this.qlrlb = qlrlb;
    }

    public Double getJkje() {
        return jkje;
    }

    public void setJkje(Double jkje) {
        this.jkje = jkje;
    }
}
